.. :changelog:

Release History
---------------

0.0.8 (2015-01-29)
++++++++++++++++++

* `scipy` removed from dependencies in library.
* `scipy` removed from dependencies in examples.

0.0.1 (2014-03-1)
++++++++++++++++++

* Conception